/* RunAvg.c -- Computes and maintains running averages
 *
 * See RunAvg.h for details
 */

#include "stddefs.h"
#include "runavg.h"
#include <stdlib.h>

struct runAvgTag {
	int		numSamples;
	double	*AVERAGE;
	int		insertAt;
};

runAvg *InitRunningAverage(int numSamples)
{
	runAvg	*temp;
	int		index;

	if (!(temp = malloc(sizeof(runAvg))))
		return NULL;

	if (!(temp -> AVERAGE = malloc(numSamples * sizeof(double)))) {
		free(temp);
		return NULL;
	}

	temp -> numSamples = numSamples;
	ClearRunningAverage(temp);

	return temp;
}

void ClearRunningAverage(runAvg *avg)
{
	int	index;

	for (index = 0; index < avg -> numSamples; index++)
		avg -> AVERAGE[index] = 0.0;

	avg -> insertAt = 0;
}

void AddToRunningAverage(runAvg *avg, double sample)
{
	avg -> AVERAGE[avg -> insertAt] = sample;
	avg -> insertAt++;
	if (avg -> insertAt >= avg -> numSamples)
		avg -> insertAt = 0;
}

double GetRunningAverage(runAvg *avg)
{
	double	sum;
	int		index;

	sum = 0;
	for (index = 0; index < avg -> numSamples; index++)
		sum += avg -> AVERAGE[index];

	return (sum / avg -> numSamples);
}

void DestroyRunningAverage(runAvg **avg)
{
	free((*avg) -> AVERAGE);
	free(*avg);
}

/* --- END of RunAvg.c --- */