/* RunAvg.h -- Computes and uses running averages
 * Author: Dylan Muir (dr.muir@student.qut.edu.au)
 * Date: December 1999
 * Modified: 10th October, 2000
 * File version: 0.02
 */

#ifndef	__runavg_h
#define	__runavg_h

/* Running average structures */

typedef	struct runAvgTag	runAvg;

/* -- Function InitRunningAverage
 * Pre: 'numSamples' is the number of samples to average over
 * Post: (A new running average variable was created and returned) ||
 *       (There was a problem with allocation && NULL was returned)
 */
runAvg *InitRunningAverage(int numSamples);

/* -- Function AddToRunningAverage
 * Pre: 'avg' has been created by 'InitRunningAverage'
 *      'sample' is a sample to add to the running average
 * Post: 'sample' has been added to 'avg'
 */
void AddToRunningAverage(runAvg *avg, double sample);

/* -- Function ClearRunningAverage
 * Pre: 'avg' has been created by 'InitRunningAverage'
 * Post: all the entries in 'avg' have been cleared to zero
 */
void ClearRunningAverage(runAvg *avg);

/* -- Function GetRunningAverage
 * Pre: 'avg' has been created by 'GetRunningAverage'
 * Post: The average has been computed and returned
 */
double GetRunningAverage(runAvg *avg);

/* -- Function DestroyRunningAverage
 * Pre: 'avg' was created by 'InitRunningAverage'
 * Post: 'avg' was destroyed and deallocated
 */
void DestroyRunningAverage(runAvg **avg);

#endif	/* __runavg_h */

/* --- END of RunAvg.h --- */
